
# **Trabalho de Desenvolvimento de uma lib reutilizavél em Projeto de Sistemas**

Uma biblioteca(lib) é um conjunto de funções desenvolvidas de forma genéricas, com o intuíto de serem distribuidas
e reutilizadas em outros sistemas e por outros programadores.


## **Etapas**

1. Desenvolvimento de uma biblioteca de criação heróis e de times de heróis;
2. Desenvolvimento de uma série de testes, a fim de testar as funçoes da lib;
3. Subir o repositório no github; 
4. Subir a lib no PiPy;


## **Integrantes do Projeto**
| Aluno | GitHub | LinkedIn |
|-------|--------|----------|
| Pedro Henrique Albani Nunes | [![GitHub](https://img.shields.io/badge/github-black?style=for-the-badge&logo=github)](https://github.com/PedroAlbaniNunes) | [![LinkedIn](https://img.shields.io/badge/linkedin-blue?style=for-the-badge&logo=linkedin)](https://www.linkedin.com/in/pedro-henrique-albani-nunes-33a729270/) |


